@@ -26,7 +26,7 @@
 #include <QDBusConnection>
 #include <QLoggingCategory>
 
-Q_LOGGING_CATEGORY(XdgDesktopPortalKdeDesktopPortal, "xdg-desktop-portal-kde-desktop-portal")
+Q_LOGGING_CATEGORY(XdgDesktopPortalKdeDesktopPortal, "xdp-kde-desktop-portal")
 
 DesktopPortal::DesktopPortal(QObject *parent)
     : QObject(parent)
@@ -37,6 +37,10 @@ DesktopPortal::DesktopPortal(QObject *parent)
     , m_inhibit(new InhibitPortal(this))
     , m_notification(new NotificationPortal(this))
     , m_print(new PrintPortal(this))
+#if SCREENCAST_ENABLED
+    , m_screenCast(new ScreenCastPortal(this))
+#endif
+    , m_screenshot(new ScreenshotPortal(this))
 {
 }
 
