@@ -29,7 +29,7 @@ class EmailPortal : public QDBusAbstractAdaptor
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.freedesktop.impl.portal.Email")
 public:
-    EmailPortal(QObject *parent);
+    explicit EmailPortal(QObject *parent);
     ~EmailPortal();
 
 public Q_SLOTS:
