@@ -21,6 +21,7 @@
 #ifndef XDG_DESKTOP_PORTAL_KDE_SCREENCAST_H
 #define XDG_DESKTOP_PORTAL_KDE_SCREENCAST_H
 
+#include <QDateTime>
 #include <QDBusAbstractAdaptor>
 #include <QDBusObjectPath>
 #include <QSize>
@@ -128,6 +129,7 @@ private:
     void initEGL();
     void initWayland();
 
+    bool m_eglInitialized;
     bool m_registryInitialized;
     bool m_streamingEnabled;
 
@@ -144,6 +146,8 @@ private:
     KWayland::Client::Registry *m_registry;
     KWayland::Client::RemoteAccessManager *m_remoteAccessManager;
 
+    QDateTime m_lastFrameTime;
+
     qint32 m_drmFd = 0; // for GBM buffer mmap
     gbm_device *m_gbmDevice = nullptr; // for passed GBM buffer retrieval
     struct {
